start_server

Function start_server 

pub async fn start_server(config: ServerConfig)
Starts the Fenrix server.

This function initializes an axum server to host the application. It serves the static client-side files and provides API endpoints for server functions.

Arguments

  • config - A ServerConfig struct containing the server’s configuration.

Panics

This function will panic if the server fails to start.