pub async fn start_server(config: ServerConfig)Expand description
Starts the Fenrix server.
This function initializes an axum server to host the application. It serves the
static client-side files and provides API endpoints for server functions.
Arguments
config- AServerConfigstruct containing the server’s configuration.
Panics
This function will panic if the server fails to start.